aboutsummaryrefslogtreecommitdiff
path: root/plugins-scripts/check_log.sh
diff options
context:
space:
mode:
authorGravatar Monitoring Plugins Development Team <devel@monitoring-plugins.org> 2014-01-18 03:40:24 -0500
committerGravatar Thomas Guyot-Sionnest <dermoth@aei.ca> 2014-01-19 14:18:47 -0500
commit63734f52ab1b4b2c17545b26fc41016d6bbd80bd (patch)
treedcd7aa3fd9a2a6a69a47d3a7e6a18d034426087a /plugins-scripts/check_log.sh
parent9db763963f3993f923619a2147e4313b09f12134 (diff)
downloadmonitoring-plugins-63734f52ab1b4b2c17545b26fc41016d6bbd80bd.tar.gz
Project rename initial commit.
This is an initial take at renaming the project to Monitoring Plugins. It's not expected to be fully complete, and it is expected to break things (The perl module for instance). More testing will be required before this goes mainline.
Diffstat (limited to 'plugins-scripts/check_log.sh')
-rwxr-xr-xplugins-scripts/check_log.sh18
1 files changed, 9 insertions, 9 deletions
diff --git a/plugins-scripts/check_log.sh b/plugins-scripts/check_log.sh
index ca5810ab..54408cbd 100755
--- a/plugins-scripts/check_log.sh
+++ b/plugins-scripts/check_log.sh
@@ -1,6 +1,6 @@
#!/bin/sh
#
# Log file pattern detector plugin for Nagios
# Written by Ethan Galstad (nagios@nagios.org)
# Last Modified: 07-31-1999
#
@@ -29,15 +29,15 @@
#
# If you use this plugin make sure to keep the following in mind:
#
# 1. The "max_attempts" value for the service should be 1, as this
# will prevent Nagios from retrying the service check (the
# next time the check is run it will not produce the same results).
#
# 2. The "notify_recovery" value for the service should be 0, so that
# Nagios does not notify you of "recoveries" for the check. Since
# pattern matches in the log file will only be reported once and not
# the next time, there will always be "recoveries" for the service, even
# though recoveries really don't apply to this type of check.
#
# 3. You *must* supply a different <old_file_log> for each service that
# you define to use this plugin script - even if the different services
@@ -85,7 +85,7 @@ print_help() {
echo ""
print_usage
echo ""
- echo "Log file pattern detector plugin for Nagios"
+ echo "Log file pattern detector plugin for monitoring"
echo ""
support
}
@@ -1,6 +1,6 @@
#!/bin/sh
#
-# Log file pattern detector plugin for Nagios
+# Log file pattern detector plugin for monitoring
# Written by Ethan Galstad (nagios@nagios.org)
# Last Modified: 07-31-1999
@@ -29,15 +29,15 @@
# If you use this plugin make sure to keep the following in mind:
#
-# 1. The "max_attempts" value for the service should be 1, as this
-# will prevent Nagios from retrying the service check (the
+# 1. The "max_attempts" value for the service should be 1, as this will
+# prevent the monitoring system from retrying the service check (the
# next time the check is run it will not produce the same results).
#
@@ -29,15 +29,15 @@
# next time the check is run it will not produce the same results).
#
-# 2. The "notify_recovery" value for the service should be 0, so that
-# Nagios does not notify you of "recoveries" for the check. Since
-# pattern matches in the log file will only be reported once and not
-# the next time, there will always be "recoveries" for the service, even
-# though recoveries really don't apply to this type of check.
+# 2. The "notify_recovery" value for the service should be 0, so that the
+# monitoring system does not notify you of "recoveries" for the check.
+# Since pattern matches in the log file will only be reported once and
+# not the next time, there will always be "recoveries" for the service,
+# even though recoveries really don't apply to this type of check.
#
# 3. You *must* supply a different <old_file_log> for each service that